@@ -18,18 +18,19 @@ use File::Basename    qw(basename);
 use Compression::Util qw(:all);
 use List::Util        qw(all min max);
 
-local $Compression::Util::LZ_MAX_CHAIN_LEN = 16;    # higher values = better compression
+use constant {CHUNK_SIZE => (1 << 15) - 1,};
 
-use constant {
-              WINDOW_SIZE => 32_768,                          # 2^15
-             };
+local $Compression::Util::LZ_MIN_LEN       = 4;                # minimum match length in LZ parsing
+local $Compression::Util::LZ_MAX_LEN       = 258;              # maximum match length in LZ parsing
+local $Compression::Util::LZ_MAX_DIST      = (1 << 15) - 1;    # maximum allowed back-reference distance in LZ parsing
+local $Compression::Util::LZ_MAX_CHAIN_LEN = 64;               # how many recent positions to remember in LZ parsing
 
-my $MAGIC  = pack('C*', 0x1f, 0x8b);    # magic MIME type
-my $CM     = chr(0x08);                 # 0x08 = DEFLATE
-my $FLAGS  = chr(0x00);                 # flags
-my $MTIME  = pack('C*', (0x00) x 4);    # modification time
-my $XFLAGS = chr(0x00);                 # extra flags
-my $OS     = chr(0x03);                 # 0x03 = Unix
+my $MAGIC  = pack('C*', 0x1f, 0x8b);                           # magic MIME type
+my $CM     = chr(0x08);                                        # 0x08 = DEFLATE
+my $FLAGS  = chr(0x00);                                        # flags
+my $MTIME  = pack('C*', (0x00) x 4);                           # modification time
+my $XFLAGS = chr(0x00);                                        # extra flags
+my $OS     = chr(0x03);                                        # 0x03 = Unix
 
 my $input  = $ARGV[0] // die "usage: $0 [input] [output.gz]\n";
 my $output = $ARGV[1] // (basename($input) . '.gz');
@@ -155,13 +156,13 @@ my $bitstring  = '';
 my $block_type = '01';                                                                 # 00 = store; 10 = LZSS + Fixed codes; 01 = LZSS + Dynamic codes
 my @CL_order   = (16, 17, 18, 0, 8, 7, 9, 6, 10, 5, 11, 4, 12, 3, 13, 2, 14, 1, 15);
 
-my ($DISTANCE_SYMBOLS, $LENGTH_SYMBOLS, $LENGTH_INDICES) = make_deflate_tables(WINDOW_SIZE);
+my ($DISTANCE_SYMBOLS, $LENGTH_SYMBOLS, $LENGTH_INDICES) = make_deflate_tables();
 
 if (eof($in_fh)) {    # empty file
     $bitstring = '1' . '10' . '0000000';
 }
 
-while (read($in_fh, (my $chunk), WINDOW_SIZE)) {
+while (read($in_fh, (my $chunk), CHUNK_SIZE)) {
 
     my $chunk_len    = length($chunk);
     my $is_last      = eof($in_fh) ? '1' : '0';
